@@ -15,12 +15,12 @@ import (
 	logf "sigs.k8s.io/controller-runtime/pkg/log"
 	"sigs.k8s.io/kustomize/v3/pkg/resource"
 
-	obv1beta2 "github.com/open-cluster-management/multicluster-observability-operator/api/v1beta2"
-	"github.com/open-cluster-management/multicluster-observability-operator/pkg/config"
-	mcoconfig "github.com/open-cluster-management/multicluster-observability-operator/pkg/config"
-	"github.com/open-cluster-management/multicluster-observability-operator/pkg/rendering/patching"
-	"github.com/open-cluster-management/multicluster-observability-operator/pkg/rendering/templates"
-	"github.com/open-cluster-management/multicluster-observability-operator/pkg/util"
+	obv1beta2 "github.com/stolostron/multicluster-observability-operator/api/v1beta2"
+	"github.com/stolostron/multicluster-observability-operator/pkg/config"
+	mcoconfig "github.com/stolostron/multicluster-observability-operator/pkg/config"
+	"github.com/stolostron/multicluster-observability-operator/pkg/rendering/patching"
+	"github.com/stolostron/multicluster-observability-operator/pkg/rendering/templates"
+	"github.com/stolostron/multicluster-observability-operator/pkg/util"
 )
 
 const (
