@@ -1,4 +1,5 @@
-// Copyright (c) 2020 Red Hat, Inc.
+// Copyright (c) 2021 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
 package util
 
@@ -14,7 +15,8 @@ import (
 )
 
 const (
-	namespace = "test-namespace"
+	name      = "test"
+	namespace = "test"
 )
 
 func TestManagedClusterAddon(t *testing.T) {
